@@ -1,4 +1,4 @@
-from kafkaAPI import KafkaAPI
+from API import KafkaAPI
 import random
 import time
 
